@@ -76,7 +76,8 @@ FSelectInstanceMultiCrit = R6Class("FSelectInstanceMultiCrit",
       super$initialize(obj, obj$domain, terminator)
 
       self$archive = ArchiveFSelect$new(search_space = self$objective$domain,
-        codomain = self$objective$codomain, check_values = check_values)
+        codomain = self$objective$codomain, check_values = check_values,
+        store_x_domain = FALSE)
       self$objective$archive = self$archive
 
       private$.objective_function = objective_function
@@ -94,7 +95,11 @@ FSelectInstanceMultiCrit = R6Class("FSelectInstanceMultiCrit",
         self$objective$task$feature_names[as.logical(x)]
       })
       xdt[, features := list(features)]
-      super$assign_result(xdt, ydt)
+      assert_data_table(xdt)
+      assert_names(names(xdt), must.include = self$search_space$ids())
+      assert_data_table(ydt)
+      assert_names(names(ydt), permutation.of = self$objective$codomain$ids())
+      private$.result = cbind(xdt, ydt)
     }
   ),
 
