@@ -1,5 +1,3 @@
-context("AutoFSelector")
-
 test_that("train and predict work", {
   skip_on_cran()
 
@@ -15,7 +13,7 @@ test_that("train and predict work", {
   at$train(task)
   expect_learner(at)
   inst = at$fselect_instance
-  a = inst$archive$data()
+  a = inst$archive$data
   expect_data_table(a, nrows = 4L)
   r = at$fselect_result
   expect_equal(r$x1, TRUE)
@@ -24,7 +22,7 @@ test_that("train and predict work", {
   expect_equal(r$x4, FALSE)
   prd = at$predict(task)
   expect_prediction(prd)
-  expect_is(at$learner$model, "rpart")
+  expect_s3_class(at$learner$model, "rpart")
 })
 
 test_that("nested resampling works", {
@@ -46,8 +44,8 @@ test_that("nested resampling works", {
   tab = as.data.table(rr)
 
   expect_data_table(tab, nrows = 2)
-  expect_data_table(tab$learner[[1]]$archive$data(), nrows = 10)
-  expect_data_table(tab$learner[[2]]$archive$data(), nrows = 10)
+  expect_data_table(tab$learner[[1]]$archive$data, nrows = 10)
+  expect_data_table(tab$learner[[2]]$archive$data, nrows = 10)
   expect_equal(tab$learner[[1]]$fselect_result$x1, TRUE)
   expect_equal(tab$learner[[1]]$fselect_result$x2, TRUE)
   expect_equal(tab$learner[[1]]$fselect_result$x3, TRUE)
@@ -137,7 +135,7 @@ test_that("AutoFSelector works with GraphLearner", {
   at$train(task)
   expect_learner(at)
   inst = at$fselect_instance
-  a = inst$archive$data()
+  a = inst$archive$data
   expect_data_table(a, nrows = 4L)
   r = at$fselect_result
   expect_equal(r$x1, TRUE)
@@ -149,4 +147,4 @@ test_that("AutoFSelector works with GraphLearner", {
   expect_equal(at$model$features, "x1")
   # Check for clone
   expect_equal(task$feature_names, c("x1", "x2", "x3" ,"x4"))
-})
\ No newline at end of file
+})
